@@ -10,8 +10,9 @@ all_servers = ['QDNSServer','QFTPServer','QHTTPProxyServer','QHTTPServer','QHTTP
 temp_honeypots = []
 
 def exit_handler():
-	print("Cleaning...")
+	print("Cleaning")
 	clean_all()
+	sleep(5)
 
 register(exit_handler)
 
@@ -20,31 +21,43 @@ def list_all_honeypots():
 		print(honeypot[1:].replace('Server','').lower())
 
 def main():
+	print("\nUse enter to exit\n")
 	try:
 		if argv[1] == "list":
 			list_all_honeypots()
+		elif argv[1] == "all":
+			for honeypot in all_servers:
+				x = globals()[honeypot]()
+				x.run_server(process=True,auto=True)
+				temp_honeypots.append(x)
 		else:
 			servers = argv[1].split(',')
 			for server in servers:
-				for honeypot in all_servers:
-					if 'q{}server'.format(server).lower() == honeypot.lower():
-						x = globals()[honeypot]()
-						x.run_server(process=True,auto=True)
-						temp_honeypots.append(x)
-			
-			wait_on_off = True
-			while wait_on_off == True:
-				try:
-					sleep(60)
-				except:
-					wait_on_off = False
-
-			print()
-			for server in temp_honeypots:
+				if ":" in server:
+					for honeypot in all_servers:
+						if 'q{}server'.format(server.split(':')[0]).lower() == honeypot.lower():
+							x = globals()[honeypot](port=int(server.split(':')[1]))
+							x.run_server(process=True)
+							temp_honeypots.append(x)
+				else:
+					for honeypot in all_servers:
+						if 'q{}server'.format(server).lower() == honeypot.lower():
+							x = globals()[honeypot]()
+							x.run_server(process=True,auto=True)
+							temp_honeypots.append(x)
+		
+		input("")
+		for server in temp_honeypots:
+			try:
 				print("Killing {}".format(server.__class__.__name__))
 				server.kill_server()
+			except:
+				pass
+
+		if len(temp_honeypots) > 0:
+			print("Please wait few seconds")
+			sleep(5)
 	except Exception as e:
-		print(e)
 		pass
 
 if __name__ == "__main__":
