@@ -104,16 +104,15 @@ class QDNSServer():
 		else:
 			self.dns_server_main()
 
-	def kill_server(self,process=False):
+	def kill_server(self,process=None):
 		try:
-			self.process.kill()
+			if self.process != None:
+				self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
 					process.send_signal(SIGTERM)
 					process.kill()
-			if self.process != None:
-				self.process.kill()
 			return True
 		except:
 			pass
