@@ -130,14 +130,31 @@ class QHTTPServer():
 				server = _q_s.mocking
 
 			def render(self, request):
-				_q_s.logs.info(["servers",{'server':'http_server','action':'connection','ip':request.getClientIP()}])
+
+				headers = {}
+
+				try:
+					def check_bytes(string):
+						if isinstance(string, bytes):
+							return string.decode()
+						else:
+							return str(string)
+
+					for item, value in dict(request.requestHeaders.getAllRawHeaders()).items():
+						headers.update({check_bytes(item):','.join(map(check_bytes, value))})
+				except:
+					pass
+
+				_q_s.logs.info(["servers",{'server':'http_server','action':'connection','ip':request.getClientIP(),'request':headers}])
+
+
 				if self.server != "":
 					request.responseHeaders.removeHeader("Server")
 					request.responseHeaders.addRawHeader("Server", self.server)
 
 				if request.method == b"GET":
 					_q_s.logs.info(["servers",{'server':'http_server','action':'get','ip':request.getClientIP()}])
-					if request.uri == "/login.html":
+					if request.uri == b"/login.html":
 						if _q_s.username != '' and _q_s.password != '':
 							request.responseHeaders.addRawHeader("Content-Type", "text/html; charset=utf-8")
 							return self.login_file
@@ -148,13 +165,14 @@ class QHTTPServer():
 				elif request.method == b"POST":
 					self.headers = request.getAllHeaders()
 					_q_s.logs.info(["servers",{'server':'http_server','action':'post','ip':request.getClientIP()}])
-					if _q_s.username != '' and _q_s.password != '':
-						form = FieldStorage(fp=request.content,headers=self.headers,environ={'REQUEST_METHOD':'POST','CONTENT_TYPE':self.headers[b'content-type'],})
-						if 'username' in form and 'password' in form:
-							if form['username'].value == _q_s.username and form['password'].value == _q_s.password:
-								_q_s.logs.info(["servers",{'server':'http_server','action':'login','status':'success','ip':request.getClientIP(),'username':_q_s.username,'password':_q_s.password}])
-							else:
-								_q_s.logs.info(["servers",{'server':'http_server','action':'login','status':'failed','ip':request.getClientIP(),'username':form['username'].value,'password':form['password'].value}])
+					if request.uri == b"/login.html":
+						if _q_s.username != '' and _q_s.password != '':
+							form = FieldStorage(fp=request.content,headers=self.headers,environ={'REQUEST_METHOD':'POST','CONTENT_TYPE':self.headers[b'content-type'],})
+							if 'username' in form and 'password' in form:
+								if form['username'].value == _q_s.username and form['password'].value == _q_s.password:
+									_q_s.logs.info(["servers",{'server':'http_server','action':'login','status':'success','ip':request.getClientIP(),'username':_q_s.username,'password':_q_s.password}])
+								else:
+									_q_s.logs.info(["servers",{'server':'http_server','action':'login','status':'failed','ip':request.getClientIP(),'username':form['username'].value,'password':form['password'].value}])
 
 					request.responseHeaders.addRawHeader("Content-Type", "text/html; charset=utf-8")
 					return self.home_file
@@ -173,7 +191,7 @@ class QHTTPServer():
 					self.port = port
 					self.process = Popen(['python3',path.realpath(__file__),'--custom','--ip',str(self.ip),'--port',str(self.port),'--username',str(self.username),'--password',str(self.password),'--mocking',str(self.mocking),'--logs',str(self._logs)])
 					if self.process.poll() is None:
-						self.logs.info(["servers",{'server':'http_server','action':'process','status':'success','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
+						self.logs.info(["servers",{'server':'http_server','action':'process','status':'success','route':'/login.html','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
 					else:
 						self.logs.info(["servers",{'server':'http_server','action':'process','status':'error','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
 				else:
@@ -181,22 +199,21 @@ class QHTTPServer():
 			elif self.close_port() and self.kill_server():
 				self.process = Popen(['python3',path.realpath(__file__),'--custom','--ip',str(self.ip),'--port',str(self.port),'--username',str(self.username),'--password',str(self.password),'--mocking',str(self.mocking),'--logs',str(self._logs)])
 				if self.process.poll() is None:
-					self.logs.info(["servers",{'server':'http_server','action':'process','status':'success','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
+					self.logs.info(["servers",{'server':'http_server','action':'process','status':'success','route':'/login.html','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
 				else:
 					self.logs.info(["servers",{'server':'http_server','action':'process','status':'error','ip':self.ip,'port':self.port,'username':self.username,'password':self.password}])
 		else:
 			self.http_server_main()
 
-	def kill_server(self,process=False):
+	def kill_server(self,process=None):
 		try:
-			self.process.kill()
+			if self.process != None:
+				self.process.kill()
 			for process in process_iter():
 				cmdline = ' '.join(process.cmdline())
 				if '--custom' in cmdline and Path(__file__).name in cmdline:
 					process.send_signal(SIGTERM)
 					process.kill()
-			if self.process != None:
-				self.process.kill()
 			return True
 		except:
 			pass
@@ -210,7 +227,7 @@ class QHTTPServer():
 			_username = username or self.username
 			_password = password or self.password
 			get('http://{}:{}'.format(_ip,_port),verify=False)
-			post('http://{}:{}'.format(_ip,_port),data={'username': (None, _username),'password': (None, _password)})
+			post('http://{}:{}/login.html'.format(_ip,_port),data={'username': (None, _username),'password': (None, _password)})
 		except:
 			pass
 
